import win32com.client
import os
import getpass

def reverse(strdata1): #문자열 뒤집기
    reverse_1 = strdata1[::-1]

    return reverse_1

def AddStartUpProgram(TheNameOfTheLink, PathToTheProgram):
    # 프로그램을 시작프로그램에 들록하는 프로그램이다.

    def plus():
        # pythoncom.CoInitialize() # remove the '#' at the beginning of the line if running in a thread.
        desktop = r'C:\ProgramData\Microsoft\Windows\Start Menu\Programs\StartUp'  # path to where you want to put the .lnk
        path = os.path.join(desktop, '{0}.lnk'.format(TheNameOfTheLink))
        target = r'{0}'.format(PathToTheProgram)

        shell = win32com.client.Dispatch("WScript.Shell")
        shortcut = shell.CreateShortCut(path)
        shortcut.Targetpath = target
        shortcut.WindowStyle = 7  # 7 - Minimized, 3 - Maximized, 1 - Normal
        shortcut.save()

    plus()

def MakeProgramShortcut(PathToLink, TheNameOfTheLink, PathToTheProgram):

    def plus():
        # pythoncom.CoInitialize() # remove the '#' at the beginning of the line if running in a thread.
        desktop = r'{0}'.format(PathToLink)  #링크파일을 위치할 경로
        path = os.path.join(desktop, '{0}.lnk'.format(TheNameOfTheLink))
        target = r'{0}'.format(PathToTheProgram)

        shell = win32com.client.Dispatch("WScript.Shell")
        shortcut = shell.CreateShortCut(path)
        shortcut.Targetpath = target
        shortcut.WindowStyle = 7  # 7 - Minimized, 3 - Maximized, 1 - Normal
        shortcut.save()

    plus()

def AddApp(ProgramName, ProgramPath):

    def plus():
        # pythoncom.CoInitialize() # remove the '#' at the beginning of the line if running in a thread.
        desktop = r'C:\ProgramData\Microsoft\Windows\Start Menu\Programs'  #링크파일을 위치할 경로
        path = os.path.join(desktop, '{0}.lnk'.format(ProgramName)) #링크파일의 이름
        target = r'{0}'.format(ProgramPath) #프로그램 경로

        shell = win32com.client.Dispatch("WScript.Shell")
        shortcut = shell.CreateShortCut(path)
        shortcut.Targetpath = target
        shortcut.WindowStyle = 7  # 7 - Minimized, 3 - Maximized, 1 - Normal
        shortcut.save()

    plus()


#ord() = example : ord("A") - 65
#chr() = example : chr("65") - "A"

def mkl(name, key, information):
    confirm1 = name.find("\\")
    confirm2 = name.find(" ")
    confirm3 = name.find("	")
    confirm4 = key.find("\\")
    confirm5 = key.find(" ")
    confirm6 = key.find("	")
    confirm7 = information.find("\\")
    confirm8 = information.find(" ")
    confirm9 = information.find("	")
    confirm10 = name.find("\n")
    confirm11 = key.find("\n")
    confirm12 = information.find("\n")
    if confirm1 > 0: #만약 confirm1의 값이 0보다 작다면
        raise Exception("There are characters that cannot be used (\,  ,	)")
    if confirm2 > 0: #만약 confirm1의 값이 0보다 작다면
        raise Exception("There are characters that cannot be used (\,  ,	)")
    if confirm3 > 0: #만약 confirm1의 값이 0보다 작다면
        raise Exception("There are characters that cannot be used (\,  ,	)")
    if confirm4 > 0: #만약 confirm1의 값이 0보다 작다면
        raise Exception("There are characters that cannot be used (\,  ,	)")
    if confirm5 > 0: #만약 confirm1의 값이 0보다 작다면
        raise Exception("There are characters that cannot be used (\,  ,	)")
    if confirm6 > 0: #만약 confirm1의 값이 0보다 작다면
        raise Exception("There are characters that cannot be used (\,  ,	)")
    if confirm7 > 0: #만약 confirm1의 값이 0보다 작다면
        raise Exception("There are characters that cannot be used (\,  ,	)")
    if confirm8 > 0: #만약 confirm1의 값이 0보다 작다면
        raise Exception("There are characters that cannot be used (\,  ,	)")
    if confirm9 > 0: #만약 confirm1의 값이 0보다 작다면
        raise Exception("There are characters that cannot be used (\,  ,	)")
    if confirm10 > 0:
        raise Exception("There are characters that cannot be used (\,  ,	)")
    if confirm11 > 0:
        raise Exception("There are characters that cannot be used (\,  ,	)")
    if confirm12 > 0:
        raise Exception("There are characters that cannot be used (\,  ,	)")
    line = name + " " + key + " " + information
    return line

def mkf(*args):
    last = ""
    for d in args:
        last += d
        last += "\n"

    return last

def getall(mkflast):
    #mklast는
    #name key information
    #name2 key2 information2
    #형태를 지니고 있다.
    getallv1 = mkflast.split("\n")
    #예를 들어서 만약 a가 2개로 측정이 됬다면
    #리스트에서는 0부터 숫자를 세니깐 -1한 값을 제외 시키면 된다.
    #
    a = len(getallv1) #개수
    a = a - 1
    del getallv1[a] #마지막 요소를 삭제한다.
    getallv2 = getallv1
    return getallv2

if __name__ == "__main__":
    t1 = mkl("testname", "testkey", "testinfo")
    t2 = mkl("testname2", "testkey2", "testinfo2")
    print(t1)
    print("\n")
    print(t2)
    print("\n")
    t3 = mkf(t1, t2)
    print(t3)
    print("\n")
    t4 = getall(t3)
    print(t4)
    print("\n")

#This file format is very weak


def plb():
    print("Loading bar")

    return 0

def loading(전체, 번째):
    entire1 = int(전체)  # 전체 개수
    th1 = int(번째)
    loadingv1 = entire1 - th1
    text1 = "□" * loadingv1
    loadingv2 = entire1 - loadingv1
    text2 = "■" * loadingv2
    print("-----[" + text2 + text1 + "]-----")

    return 0

def howd():
    print("Hello, World!")


import cryptocode

def encrypt(text, key):
    str_encoded = cryptocode.encrypt(text, key)
    return str_encoded

def decrypt(encrypted_text, key):
    str_decoded = cryptocode.decrypt(encrypted_text, key)
    return str_decoded